==> PqrUploadModule-0.0.6.tar.gz: PqrUploadModule-0.0.6/setup.py <==
import setuptools
from distutils.core import setup
setup(
  name = 'PqrUploadModule',         # How you named your package folder (MyLib)
  packages = ['PqrUploadModule'],   # Chose the same as "name"
  version = '0.0.6',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Connection AT-TD',   # Give a short description about your library
  author = 'ppp',                   # Type in your name
  author_email = 'petronije2002@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/petronije2002/PqrUpload/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/petronije2002/PqrUpload/archive/0.0.5b.tar.gz',    # I explain this later on
  keywords = ['Autotask', 'Topdesk', 'Connection'],   # Keywords that define your package best
  install_requires = setuptools.find_packages(),
#   install_requires=[            # I get to this in a second
#           'validators',
#           'beautifulsoup4',
#       ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> PqrUploadModule-0.0.7.tar.gz: PqrUploadModule-0.0.7/setup.py <==
import setuptools
from distutils.core import setup
setup(
  name = 'PqrUploadModule',         # How you named your package folder (MyLib)
  packages = ['PqrUploadModule'],   # Chose the same as "name"
  version = '0.0.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Connection AT-TD',   # Give a short description about your library
  author = 'ppp',                   # Type in your name
  author_email = 'petronije2002@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/petronije2002/PqrUpload/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/petronije2002/PqrUpload/archive/0.0.6.tar.gz',    # I explain this later on
  keywords = ['Autotask', 'Topdesk', 'Connection'],   # Keywords that define your package best
  install_requires = setuptools.find_packages(),
#   install_requires=[            # I get to this in a second
#           'validators',
#           'beautifulsoup4',
#       ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
